@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -65,6 +65,11 @@ if ( $] eq '5.010' ) {
 #pod
 #pod If an error occurs, a L<MongoDB::Error> object will be thrown.
 #pod
+#pod B<NOTE>: To connect to a replica set, a replica set name must be provided.
+#pod For example, if the set name is "setA":
+#pod
+#pod     $client = MongoDB->connect("mongodb://example.com/?replicaSet=setA");
+#pod
 #pod =cut
 
 sub connect {
@@ -101,42 +106,21 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
-This is Release Candidate 1 (RC1) for v1.0.0.
-
-=head1 RELEASE CANDIDATE NOTICE
-
-The v0.999.999.4 driver is the first release candidate for v1.0.0.
-We expect no API changes between now and the final stable release.
-
-It is released for the community to begin testing in preparation for
-migration to v1.0.0.
-
-Users are B<strongly> encourgaed to read L<MongoDB::Upgrading> for
-details on changes and how to upgrade applications.
-
-=head2 Notable changes
-
-The Release Candidate 1 driver is significantly faster than the Beta 3
-driver.
-
-Other changes from Beta 3 are minor.
+B<NOTE:> The v1.1.x versions are development releases in advance of the
+MongoDB Perl Driver v1.2.0. They are available for evaluation and testing
+and should not be used in production.  Most notably, they include support
+for features in MongoDB 3.2 release candidates.
 
 =head1 SYNOPSIS
 
     use MongoDB;
 
-    # short-hand
     my $client     = MongoDB->connect('mongodb://localhost');
     my $collection = $client->ns('foo.bar'); # database foo, collection bar
-    my $id         = $collection->insert({ some => 'data' });
-    my $data       = $collection->find_one({ _id => $id });
-
-    # long-hand
-    my $client     = MongoDB::MongoClient->new(host => 'mongodb://localhost');
-    my $database   = $client->get_database( 'foo' );
-    my $collection = $database->get_collection( 'bar' );
+    my $result     = $collection->insert_one({ some => 'data' });
+    my $data       = $collection->find_one({ _id => $result->inserted_id });
 
 =head1 DESCRIPTION
 
@@ -225,13 +209,18 @@ for L<MongoDB::MongoClient::new|MongoDB::MongoClient/ATTRIBUTES>.
 
 If an error occurs, a L<MongoDB::Error> object will be thrown.
 
+B<NOTE>: To connect to a replica set, a replica set name must be provided.
+For example, if the set name is "setA":
+
+    $client = MongoDB->connect("mongodb://example.com/?replicaSet=setA");
+
 =for Pod::Coverage force_double
 force_int
 read_documents
 
 =head1 SEMANTIC VERSIONING SCHEME
 
-Starting with MongoDB C<v1.0.0>, the driver will revert to the more familiar
+Starting with MongoDB C<v1.0.0>, the driver reverts to the more familiar
 three-part version-tuple numbering scheme used by both Perl and MongoDB:
 C<vX.Y.Z>
 
@@ -301,7 +290,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Bernard Gorman Brendan W. McAdams Casey Rojas chansen Christian Sturm Walde Colin Cyr danny David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams mapbuh Matthew Shopsin Michael Langner Rotmanov Mike Dirolf nightlord nightsailer Nuno Carvalho Orlando Vazquez Othello Maurer Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney.Jackson Xtreak
+=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Bernard Gorman Brendan W. McAdams Casey Rojas Christian Sturm Walde Colin Cyr Danny Raetzsch David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Hao Wu Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Josh Matthews Joshua Juran J. Stewart Kamil Slowikowski Ken Williams Matthew Shopsin Michael Langner Rotmanov Mike Dirolf Nickola Trupcheff Niko Tyni Nuno Carvalho Orlando Vazquez Othello Maurer Pan Fan Rahul Dhodapkar Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney Jackson Xtreak Zhihong Zhang
 
 =over 4
 
@@ -335,7 +324,7 @@ Casey Rojas <casey.j.rojas@gmail.com>
 
 =item *
 
-chansen <chansen@cpan.org>
+Christian Hansen <chansen@cpan.org>
 
 =item *
 
@@ -351,7 +340,7 @@ Colin Cyr <ccyr@sailingyyc.com>
 
 =item *
 
-danny <danny@paperskymedia.com>
+Danny Raetzsch <danny@paperskymedia.com>
 
 =item *
 
@@ -391,6 +380,10 @@ Graham Barr <gbarr@pobox.com>
 
 =item *
 
+Hao Wu <echowuhao@gmail.com>
+
+=item *
+
 Jason Carey <jason.carey@mongodb.com>
 
 =item *
@@ -407,6 +400,10 @@ Joseph Harnish <bigjoe1008@gmail.com>
 
 =item *
 
+Josh Matthews <joshua.matthews@mongodb.com>
+
+=item *
+
 Joshua Juran <jjuran@metamage.com>
 
 =item *
@@ -423,10 +420,6 @@ Ken Williams <kwilliams@cpan.org>
 
 =item *
 
-mapbuh <n.trupcheff@gmail.com>
-
-=item *
-
 Matthew Shopsin <matt.shopsin@mongodb.com>
 
 =item *
@@ -443,11 +436,11 @@ Mike Dirolf <mike@mongodb.com>
 
 =item *
 
-nightlord <zzh_621@yahoo.com>
+Nickola Trupcheff <n.trupcheff@gmail.com>
 
 =item *
 
-nightsailer <nightsailer@gmail.com>
+Niko Tyni <ntyni@debian.org>
 
 =item *
 
@@ -463,6 +456,14 @@ Othello Maurer <omaurer@venda.com>
 
 =item *
 
+Pan Fan <nightsailer@gmail.com>
+
+=item *
+
+Rahul Dhodapkar <rahul@mongodb.com>
+
+=item *
+
 Robin Lee <cheeselee@fedoraproject.org>
 
 =item *
@@ -495,12 +496,16 @@ Uwe Voelker <uwe.voelker@xing.com>
 
 =item *
 
-Whitney.Jackson <whjackson@gmail.com>
+Whitney Jackson <whjackson@gmail.com>
 
 =item *
 
 Xtreak <tirkarthi@users.noreply.github.com>
 
+=item *
+
+Zhihong Zhang <zzh_621@yahoo.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
