@@ -20,7 +20,7 @@ package MongoDB::BSON;
 # ABSTRACT: Tools for serializing and deserializing data in BSON form
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 
 use XSLoader;
@@ -63,7 +63,18 @@ our $_boolean_false = false;
 #pod other keys.  The callback must return a scalar value representing the dbref
 #pod (e.g. a document, an object, etc.)
 #pod
-#pod The default returns the DBRef hash reference without modification.
+#pod The default C<dbref_callback> returns the DBRef hash reference without
+#pod modification.
+#pod
+#pod Note: in L<MongoDB::MongoClient>, when no L<MongoDB::BSON> object is
+#pod provided as the C<bson_codec> attribute, L<MongoDB:MongoClient> creates a
+#pod B<custom> L<MongoDB::BSON> object that inflates DBRefs into
+#pod L<MongoDB::DBRef> objects using a custom C<dbref_callback>:
+#pod
+#pod     dbref_callback => sub { return MongoDB::DBRef->new(shift) },
+#pod
+#pod Object-database mappers may wish to implement alternative C<dbref_callback>
+#pod attributes to provide whatever semantics they require.
 #pod
 #pod =cut
 
@@ -77,8 +88,8 @@ has dbref_callback => (
 #pod
 #pod Sets the type of object which is returned for BSON DateTime fields. The default
 #pod is L<DateTime>. Other acceptable values are L<Time::Moment>, L<DateTime::Tiny>
-#pod and C<undef>. The latter will give you the raw epoch value rather than an
-#pod object.
+#pod and C<undef>. The latter will give you the raw epoch value (possibly as a
+#pod floating point value) rather than an object.
 #pod
 #pod =cut
 
@@ -295,7 +306,7 @@ MongoDB::BSON - Tools for serializing and deserializing data in BSON form
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -324,14 +335,25 @@ The hash reference will have keys C<$ref> and C<$id> and may have C<$db> and
 other keys.  The callback must return a scalar value representing the dbref
 (e.g. a document, an object, etc.)
 
-The default returns the DBRef hash reference without modification.
+The default C<dbref_callback> returns the DBRef hash reference without
+modification.
+
+Note: in L<MongoDB::MongoClient>, when no L<MongoDB::BSON> object is
+provided as the C<bson_codec> attribute, L<MongoDB:MongoClient> creates a
+B<custom> L<MongoDB::BSON> object that inflates DBRefs into
+L<MongoDB::DBRef> objects using a custom C<dbref_callback>:
+
+    dbref_callback => sub { return MongoDB::DBRef->new(shift) },
+
+Object-database mappers may wish to implement alternative C<dbref_callback>
+attributes to provide whatever semantics they require.
 
 =head2 dt_type
 
 Sets the type of object which is returned for BSON DateTime fields. The default
 is L<DateTime>. Other acceptable values are L<Time::Moment>, L<DateTime::Tiny>
-and C<undef>. The latter will give you the raw epoch value rather than an
-object.
+and C<undef>. The latter will give you the raw epoch value (possibly as a
+floating point value) rather than an object.
 
 =head2 error_callback
 
