@@ -19,7 +19,7 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::OID;
@@ -63,6 +63,18 @@ has 'ordered' => (
     required => 1,
 );
 
+#pod =attr bypassDocumentValidation
+#pod
+#pod A boolean for whether or not operations should bypass document validation.
+#pod Default is false.
+#pod
+#pod =cut
+
+has 'bypassDocumentValidation' => (
+    is       => 'ro',
+    isa      => Bool,
+);
+
 has '_executed' => (
     is       => 'rw',
     isa      => Bool,
@@ -233,12 +245,13 @@ sub execute {
     $write_concern ||= $self->collection->write_concern;
 
     my $op = MongoDB::Op::_BulkWrite->_new(
-        db_name       => $self->_database->name,
-        coll_name     => $self->collection->name,
-        queue         => $self->_queue,
-        ordered       => $self->ordered,
-        bson_codec    => $self->collection->bson_codec,
-        write_concern => $write_concern,
+        db_name                  => $self->_database->name,
+        coll_name                => $self->collection->name,
+        queue                    => $self->_queue,
+        ordered                  => $self->ordered,
+        bypassDocumentValidation => $self->bypassDocumentValidation,
+        bson_codec               => $self->collection->bson_codec,
+        write_concern            => $write_concern,
     );
 
     return $self->_client->send_write_op( $op );
@@ -268,7 +281,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -339,6 +352,11 @@ The L<MongoDB::Collection> where the operations are to be performed.
 A boolean for whether or not operations should be ordered (true) or
 unordered (false).
 
+=head2 bypassDocumentValidation
+
+A boolean for whether or not operations should bypass document validation.
+Default is false.
+
 =head1 METHODS
 
 =head2 find
