@@ -20,7 +20,7 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
@@ -32,6 +32,7 @@ use MongoDB::_Types qw(
     BSONCodec
     NonNegNum
     ReadPreference
+    ReadConcern
     WriteConcern
 );
 use Types::Standard qw(
@@ -44,7 +45,7 @@ use Moo;
 use Try::Tiny;
 use namespace::clean -except => 'meta';
 
-has _client => ( 
+has _client => (
     is       => 'ro',
     isa      => InstanceOf['MongoDB::MongoClient'],
     required => 1,
@@ -93,6 +94,23 @@ has write_concern => (
     coerce   => WriteConcern->coercion,
 );
 
+#pod =attr read_concern
+#pod
+#pod A L<MongoDB::ReadConcern> object.  May be initialized with a hash
+#pod reference or a string that will be coerced into the level of read
+#pod concern.
+#pod
+#pod By default it will be inherited from a L<MongoDB::MongoClient> object.
+#pod
+#pod =cut
+
+has read_concern => (
+    is       => 'ro',
+    isa      => ReadConcern,
+    required => 1,
+    coerce   => ReadConcern->coercion,
+);
+
 #pod =attr max_time_ms
 #pod
 #pod Specifies the maximum amount of time in milliseconds that the server should use
@@ -234,6 +252,7 @@ sub get_collection {
     return MongoDB::Collection->new(
         read_preference => $self->read_preference,
         write_concern   => $self->write_concern,
+        read_concern    => $self->read_concern,
         bson_codec      => $self->bson_codec,
         max_time_ms     => $self->max_time_ms,
         ( $options ? %$options : () ),
@@ -345,24 +364,9 @@ sub run_command {
     return $obj->output;
 }
 
-#pod =method eval ($code, $args?, $nolock?)
-#pod
-#pod     my $output = $database->eval('function(x) { return "hello, "+x; }', ["world"]);
-#pod
-#pod Evaluate a JavaScript expression on the Mongo server. The C<$code> argument can
-#pod be a string or an instance of L<MongoDB::Code>.  The C<$args> are an optional
-#pod array of arguments to be passed to the C<$code> function.  C<$nolock> (default
-#pod C<false>) prevents the eval command from taking the global write lock before
-#pod evaluating the JavaScript.
-#pod
-#pod C<eval> is useful if you need to touch a lot of data lightly; in such a scenario
-#pod the network transfer of the data could be a bottleneck. The C<$code> argument
-#pod must be a JavaScript function. C<$args> is an array of parameters that will be
-#pod passed to the function.  C<$nolock> is a L<boolean> value.  For more examples of
-#pod using eval see
-#pod L<http://www.mongodb.org/display/DOCS/Server-side+Code+Execution#Server-sideCodeExecution-Using{{db.eval%28%29}}>.
-#pod
-#pod =cut
+#--------------------------------------------------------------------------#
+# deprecated methods
+#--------------------------------------------------------------------------#
 
 sub eval {
     my ($self, $code, $args, $nolock) = @_;
@@ -383,10 +387,6 @@ sub eval {
     }
 }
 
-#--------------------------------------------------------------------------#
-# deprecated methods
-#--------------------------------------------------------------------------#
-
 sub last_error {
     my ( $self, $opt ) = @_;
     return $self->run_command( [ getlasterror => 1, ( $opt ? %$opt : () ) ] );
@@ -407,7 +407,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -475,6 +475,14 @@ A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 reference that will be coerced into a new MongoDB::WriteConcern object.
 By default it will be inherited from a L<MongoDB::MongoClient> object.
 
+=head2 read_concern
+
+A L<MongoDB::ReadConcern> object.  May be initialized with a hash
+reference or a string that will be coerced into the level of read
+concern.
+
+By default it will be inherited from a L<MongoDB::MongoClient> object.
+
 =head2 max_time_ms
 
 Specifies the maximum amount of time in milliseconds that the server should use
@@ -607,23 +615,6 @@ There are a few examples of database commands in the
 L<MongoDB::Examples/"DATABASE COMMANDS"> section.  See also core documentation
 on database commands: L<http://dochub.mongodb.org/core/commands>.
 
-=head2 eval ($code, $args?, $nolock?)
-
-    my $output = $database->eval('function(x) { return "hello, "+x; }', ["world"]);
-
-Evaluate a JavaScript expression on the Mongo server. The C<$code> argument can
-be a string or an instance of L<MongoDB::Code>.  The C<$args> are an optional
-array of arguments to be passed to the C<$code> function.  C<$nolock> (default
-C<false>) prevents the eval command from taking the global write lock before
-evaluating the JavaScript.
-
-C<eval> is useful if you need to touch a lot of data lightly; in such a scenario
-the network transfer of the data could be a bottleneck. The C<$code> argument
-must be a JavaScript function. C<$args> is an array of parameters that will be
-passed to the function.  C<$nolock> is a L<boolean> value.  For more examples of
-using eval see
-L<http://www.mongodb.org/display/DOCS/Server-side+Code+Execution#Server-sideCodeExecution-Using{{db.eval%28%29}}>.
-
 =for Pod::Coverage last_error
 
 =head1 DEPRECATIONS
