@@ -19,7 +19,7 @@ package MongoDB::IndexView;
 # ABSTRACT: Index management for a collection
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
@@ -375,7 +375,7 @@ MongoDB::IndexView - Index management for a collection
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -396,7 +396,7 @@ version v0.999.999.6
     $name = $indexes->create_one( [ x => 1, y => -1 ], { unique => 1 } );
 
     @names = $indexes->create_many(
-        { keys => [ x => 1, y => -1 ], { unique => 1 } },
+        { keys => [ x => 1, y => -1 ], options => { unique => 1 } },
         { keys => [ z => 1 ] },
     );
 
