@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 use MongoDB;
@@ -30,8 +30,10 @@ use MongoDB::Cursor;
 use MongoDB::DBRef;
 use MongoDB::Error;
 use MongoDB::Op::_Command;
+use MongoDB::Op::_FSyncUnlock;
 use MongoDB::ReadPreference;
 use MongoDB::WriteConcern;
+use MongoDB::ReadConcern;
 use MongoDB::_Topology;
 use MongoDB::_Constants;
 use MongoDB::_Credential;
@@ -57,9 +59,11 @@ use Types::Standard qw(
     Bool
     HashRef
     InstanceOf
+    Undef
     Int
     Num
     Str
+    Maybe
 );
 
 use namespace::clean -except => 'meta';
@@ -88,6 +92,10 @@ $MongoDB::BSON::char = '$';
 #pod
 #pod Defaults to the connection string URI C<mongodb://localhost:27017>.
 #pod
+#pod For IPv6 support, you must have a recent version of L<IO::Socket::IP>
+#pod installed.  This module ships with the Perl core since v5.20.0 and is
+#pod available on CPAN for older Perls.
+#pod
 #pod =cut
 
 has host => (
@@ -172,7 +180,21 @@ sub _build_auth_mechanism_properties {
 #pod from L<MongoDB::BSON>.  It may be initialized with a hash reference that will
 #pod be coerced into a new L<MongoDB::BSON> object.
 #pod
-#pod If not provided, one will be generated from deprecated configuration options.
+#pod If not provided, one will be generated as follows:
+#pod
+#pod     MongoDB::BSON->new(
+#pod         dbref_callback => sub { return MongoDB::DBRef->new(shift) },
+#pod         dt_type        => $client->dt_type,
+#pod         prefer_numeric => $MongoDB::BSON::looks_like_number || 0,
+#pod         (
+#pod             $MongoDB::BSON::char ne '$' ?
+#pod                 ( op_char => $MongoDB::BSON::char ) : ()
+#pod         ),
+#pod     );
+#pod
+#pod This will inflate all DBRefs to L<MongoDB::DBRef> objects, set C<dt_type>
+#pod based on the client's C<db_type> accessor, and set the C<prefer_numeric>
+#pod and C<op_char> attributes based on the deprecated legacy global variables.
 #pod
 #pod =cut
 
@@ -667,7 +689,7 @@ sub _build_socket_timeout_ms {
 #pod B<You are strongly encouraged to use your own CA file for increased security>.
 #pod
 #pod Server hostnames are also validated against the CN name in the server
-#pod certificate using C<< SSL_verifycn_scheme => 'default' >>.  You can use the
+#pod certificate using C<< SSL_verifycn_scheme => 'http' >>.  You can use the
 #pod scheme 'none' to disable this check.
 #pod
 #pod B<Disabling certificate or hostname verification is a security risk and is not
@@ -734,12 +756,9 @@ sub _build_username {
 #pod
 #pod =over 4
 #pod
-#pod =item * C<-1> Errors ignored. Do not use this.
-#pod
 #pod =item * C<0> Unacknowledged. MongoClient will B<NOT> wait for an acknowledgment that
 #pod the server has received and processed the request. Older documentation may refer
-#pod to this as "fire-and-forget" mode. You must call C<getLastError> manually to check
-#pod if a request succeeds. This option is not recommended.
+#pod to this as "fire-and-forget" mode.  This option is not recommended.
 #pod
 #pod =item * C<1> Acknowledged. This is the default. MongoClient will wait until the
 #pod primary MongoDB acknowledges the write.
@@ -754,11 +773,9 @@ sub _build_username {
 #pod
 #pod =back
 #pod
-#pod In MongoDB v2.0+, you can "tag" replica members. With "tagging" you can specify a
-#pod new "getLastErrorMode" where you can create new
-#pod rules on how your data is replicated. To used you getLastErrorMode, you pass in the
-#pod name of the mode to the C<w> parameter. For more information see:
-#pod http://www.mongodb.org/display/DOCS/Data+Center+Awareness
+#pod In MongoDB v2.0+, you can "tag" replica members. With "tagging" you can
+#pod specify a custom write concern For more information see L<Data Center
+#pod Awareness|http://docs.mongodb.org/manual/data-center-awareness/>
 #pod
 #pod This may be set in a connection string with the C<w> option.
 #pod
@@ -766,7 +783,7 @@ sub _build_username {
 
 has w => (
     is      => 'lazy',
-    isa     => Int|Str,
+    isa     => Int|Str|Undef,
     builder => '_build_w',
 );
 
@@ -775,14 +792,14 @@ sub _build_w {
     return $self->__uri_or_else(
         u => 'w',
         e => 'w',
-        d => 1,
+        d => undef,
     );
 }
 
 #pod =attr wtimeout
 #pod
-#pod The number of milliseconds an operation should wait for C<w> slaves to replicate
-#pod it.
+#pod The number of milliseconds an operation should wait for C<w> secondaries to
+#pod replicate it.
 #pod
 #pod Defaults to 1000 (1 second).
 #pod
@@ -807,15 +824,50 @@ sub _build_wtimeout {
     );
 }
 
+#pod =attr read_concern_level
+#pod
+#pod The read concern level determines the consistency level required
+#pod of data being read.
+#pod
+#pod The default level is C<undef>, which means the server will use its configured
+#pod default.
+#pod
+#pod If the level is set to "local", reads will return the latest data a server has
+#pod locally.
+#pod
+#pod Additional levels are storage engine specific.  See L<Read
+#pod Concern|http://docs.mongodb.org/manual/search/?query=readConcern> in the MongoDB
+#pod documentation for more details.
+#pod
+#pod This may be set in a connection string with the the C<readConcernLevel> option.
+#pod
+#pod =cut
+
+has read_concern_level => (
+    is      => 'lazy',
+    isa     => Maybe [Str],
+    builder => '_build_read_concern_level',
+);
+
+sub _build_read_concern_level {
+    my ($self) = @_;
+    return $self->__uri_or_else(
+        u => 'readconcernlevel',
+        e => 'read_concern_level',
+        d => undef,
+    );
+}
+
 #--------------------------------------------------------------------------#
 # deprecated public attributes
 #--------------------------------------------------------------------------#
 
 #pod =attr dt_type (DEPRECATED AND READ-ONLY)
 #pod
-#pod Sets the type of object which is returned for DateTime fields. The default is
-#pod L<DateTime>. Other acceptable values are L<DateTime::Tiny>, L<Time::Moment> and
-#pod C<undef>. The latter will give you the raw epoch value rather than an object.
+#pod Sets the type of object which is returned for DateTime fields. The default
+#pod is L<DateTime>. Other acceptable values are L<DateTime::Tiny>,
+#pod L<Time::Moment> and C<undef>. The latter will give you the raw epoch value
+#pod (possibly as a floating point value) rather than an object.
 #pod
 #pod This will be used to construct L</bson_codec> object if one is not provided.
 #pod
@@ -948,6 +1000,30 @@ sub _build__write_concern {
     );
 }
 
+#pod =method read_concern
+#pod
+#pod Returns a L<MongoDB::ReadConcern> object constructed from
+#pod L</read_concern_level>.
+#pod
+#pod =cut
+
+has _read_concern => (
+    is     => 'lazy',
+    isa    => InstanceOf['MongoDB::ReadConcern'],
+    reader   => 'read_concern',
+    init_arg => undef,
+    builder  => '_build__read_concern',
+);
+
+sub _build__read_concern {
+    my ($self) = @_;
+
+    return MongoDB::ReadConcern->new(
+        ( $self->read_concern_level ?
+            ( level => $self->read_concern_level ) : () ),
+    );
+}
+
 #--------------------------------------------------------------------------#
 # private attributes
 #--------------------------------------------------------------------------#
@@ -1044,7 +1120,7 @@ has _uri => (
 
 sub _build__uri {
     my ($self) = @_;
-    if ( $self->host =~ m{^mongodb://} ) {
+    if ( $self->host =~ m{^\w+://} ) {
         return MongoDB::_URI->new( uri => $self->host );
     }
     else {
@@ -1082,6 +1158,7 @@ my @deferred_options = qw(
   password
   w
   wtimeout
+  read_concern_level
 );
 
 around BUILDARGS => sub {
@@ -1400,6 +1477,7 @@ sub get_database {
     return MongoDB::Database->new(
         read_preference => $self->read_preference,
         write_concern   => $self->write_concern,
+        read_concern    => $self->read_concern,
         bson_codec      => $self->bson_codec,
         max_time_ms     => $self->max_time_ms,
         ( $options ? %$options : () ),
@@ -1480,8 +1558,13 @@ sub fsync {
 sub fsync_unlock {
     my ($self) = @_;
 
-    # Have to fetch from a special collection to unlock.
-    return $self->get_database('admin')->get_collection('$cmd.sys.unlock')->find_one();
+    my $op = MongoDB::Op::_FSyncUnlock->_new(
+        db_name    => 'admin',
+        client     => $self,
+        bson_codec => $self->bson_codec,
+    );
+
+    return $self->send_read_op($op);
 }
 
 
@@ -1499,7 +1582,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.999.6
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -1519,6 +1602,11 @@ version v0.999.999.6
         replica_set_name => 'myset',
     );
 
+    # connect to a replica set with URI (set name *required*)
+    my $client = MongoDB::MongoClient->new(
+        host => "mongodb://mongo1.example.com,mongo2.example.com/?replicaSet=myset",
+    );
+
     my $db = $client->get_database("test");
     my $coll = $db->get_collection("people");
 
@@ -1565,6 +1653,10 @@ STRING URI> with a seed list of one or more servers plus connection options.
 
 Defaults to the connection string URI C<mongodb://localhost:27017>.
 
+For IPv6 support, you must have a recent version of L<IO::Socket::IP>
+installed.  This module ships with the Perl core since v5.20.0 and is
+available on CPAN for older Perls.
+
 =head2 auth_mechanism
 
 This attribute determines how the client authenticates with the server.
@@ -1624,7 +1716,21 @@ An object that provides the C<encode_one> and C<decode_one> methods, such as
 from L<MongoDB::BSON>.  It may be initialized with a hash reference that will
 be coerced into a new L<MongoDB::BSON> object.
 
-If not provided, one will be generated from deprecated configuration options.
+If not provided, one will be generated as follows:
+
+    MongoDB::BSON->new(
+        dbref_callback => sub { return MongoDB::DBRef->new(shift) },
+        dt_type        => $client->dt_type,
+        prefer_numeric => $MongoDB::BSON::looks_like_number || 0,
+        (
+            $MongoDB::BSON::char ne '$' ?
+                ( op_char => $MongoDB::BSON::char ) : ()
+        ),
+    );
+
+This will inflate all DBRefs to L<MongoDB::DBRef> objects, set C<dt_type>
+based on the client's C<db_type> accessor, and set the C<prefer_numeric>
+and C<op_char> attributes based on the deprecated legacy global variables.
 
 =head2 connect_timeout_ms
 
@@ -1872,7 +1978,7 @@ C<< SSL_verify_mode => 0x00 >>.
 B<You are strongly encouraged to use your own CA file for increased security>.
 
 Server hostnames are also validated against the CN name in the server
-certificate using C<< SSL_verifycn_scheme => 'default' >>.  You can use the
+certificate using C<< SSL_verifycn_scheme => 'http' >>.  You can use the
 scheme 'none' to disable this check.
 
 B<Disabling certificate or hostname verification is a security risk and is not
@@ -1905,12 +2011,9 @@ The client I<write concern>.
 
 =over 4
 
-=item * C<-1> Errors ignored. Do not use this.
-
 =item * C<0> Unacknowledged. MongoClient will B<NOT> wait for an acknowledgment that
 the server has received and processed the request. Older documentation may refer
-to this as "fire-and-forget" mode. You must call C<getLastError> manually to check
-if a request succeeds. This option is not recommended.
+to this as "fire-and-forget" mode.  This option is not recommended.
 
 =item * C<1> Acknowledged. This is the default. MongoClient will wait until the
 primary MongoDB acknowledges the write.
@@ -1925,18 +2028,16 @@ number for more replicas.
 
 =back
 
-In MongoDB v2.0+, you can "tag" replica members. With "tagging" you can specify a
-new "getLastErrorMode" where you can create new
-rules on how your data is replicated. To used you getLastErrorMode, you pass in the
-name of the mode to the C<w> parameter. For more information see:
-http://www.mongodb.org/display/DOCS/Data+Center+Awareness
+In MongoDB v2.0+, you can "tag" replica members. With "tagging" you can
+specify a custom write concern For more information see L<Data Center
+Awareness|http://docs.mongodb.org/manual/data-center-awareness/>
 
 This may be set in a connection string with the C<w> option.
 
 =head2 wtimeout
 
-The number of milliseconds an operation should wait for C<w> slaves to replicate
-it.
+The number of milliseconds an operation should wait for C<w> secondaries to
+replicate it.
 
 Defaults to 1000 (1 second).
 
@@ -1944,11 +2045,29 @@ See C<w> above for more information.
 
 This may be set in a connection string with the C<wTimeoutMS> option.
 
+=head2 read_concern_level
+
+The read concern level determines the consistency level required
+of data being read.
+
+The default level is C<undef>, which means the server will use its configured
+default.
+
+If the level is set to "local", reads will return the latest data a server has
+locally.
+
+Additional levels are storage engine specific.  See L<Read
+Concern|http://docs.mongodb.org/manual/search/?query=readConcern> in the MongoDB
+documentation for more details.
+
+This may be set in a connection string with the the C<readConcernLevel> option.
+
 =head2 dt_type (DEPRECATED AND READ-ONLY)
 
-Sets the type of object which is returned for DateTime fields. The default is
-L<DateTime>. Other acceptable values are L<DateTime::Tiny>, L<Time::Moment> and
-C<undef>. The latter will give you the raw epoch value rather than an object.
+Sets the type of object which is returned for DateTime fields. The default
+is L<DateTime>. Other acceptable values are L<DateTime::Tiny>,
+L<Time::Moment> and C<undef>. The latter will give you the raw epoch value
+(possibly as a floating point value) rather than an object.
 
 This will be used to construct L</bson_codec> object if one is not provided.
 
@@ -2002,6 +2121,11 @@ C<get_collection>.
 Returns a L<MongoDB::WriteConcern> object constructed from L</w>, L</write_concern>
 and L</j>.
 
+=head2 read_concern
+
+Returns a L<MongoDB::ReadConcern> object constructed from
+L</read_concern_level>.
+
 =head2 topology_type
 
 Returns an enumerated topology type.  If the L</replica_set_name> is
