@@ -19,7 +19,7 @@ package MongoDB::Op::_Aggregate;
 # Encapsulate aggregate operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 
@@ -83,6 +83,9 @@ sub execute {
     # will reject it as unrecognized
     delete $options->{maxTimeMS} unless $is_2_6;
 
+    # bypassDocumentValidation isn't available until 3.2 (wire version 4)
+    delete $options->{bypassDocumentValidation} unless $link->accepts_wire_version(4);
+
     # If 'cursor' is explicitly false, we disable using cursors, even
     # for MongoDB 2.6+.  This allows users operating with a 2.6+ mongos
     # and pre-2.6 mongod in shards to avoid fatal errors.  This
@@ -114,9 +117,15 @@ sub execute {
         delete $options->{cursor};
     }
 
+    # read concerns are ignored if the last stage is $out
+    my ($last_op) = keys %{ $self->pipeline->[-1] };
+
     my @command = (
         aggregate => $self->coll_name,
         pipeline  => $self->pipeline,
+        ($last_op eq '$out' ? () :
+            ($link->accepts_wire_version(4) ?
+                @{ $self->read_concern->as_args } : () ) ),
         %$options,
     );
 
@@ -141,7 +150,7 @@ sub execute {
             _batch_size   => 1,
             _cursor_at    => 0,
             _limit        => 0,
-            _cursor_id    => MongoDB::QueryResult::_pack_cursor_id(0),
+            _cursor_id    => 0,
             _cursor_start => 0,
             _cursor_flags => {},
             _cursor_num   => 1,
