@@ -19,7 +19,7 @@ package MongoDB::Op::_Command;
 # Encapsulate running a command and returning a MongoDB::CommandResult
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 
@@ -64,7 +64,8 @@ sub execute {
     my ( $self, $link, $topology_type ) = @_;
     $topology_type ||= 'Single'; # if not specified, assume direct
 
-    $self->_apply_read_prefs( $link, $topology_type );
+    # $query is passed as a reference because it *may* be replaced
+    $self->_apply_read_prefs( $link, $topology_type, $self->query_flags, \$self->query);
 
     my $res = MongoDB::CommandResult->_new(
         output => $self->_send_command( $link, $self->query, $self->query_flags ),
