@@ -19,7 +19,7 @@ package MongoDB::Op::_Delete;
 # Encapsulate a delete operation; returns a MongoDB::DeleteResult
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 
@@ -90,7 +90,7 @@ sub execute {
                 [
                     delete       => $self->coll_name,
                     deletes      => [$op_doc],
-                    writeConcern => $self->write_concern->as_struct,
+                    @{ $self->write_concern->as_args },
                 ],
                 $op_doc,
                 "MongoDB::DeleteResult"
