@@ -19,7 +19,7 @@ package MongoDB::Op::_Distinct;
 # Encapsulate distinct operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 
@@ -91,6 +91,8 @@ sub execute {
         distinct => $self->coll_name,
         key      => $self->fieldname,
         query    => $filter,
+        ($link->accepts_wire_version(4) ?
+            @{ $self->read_concern->as_args } : ()),
         %$options
     );
 
