@@ -17,7 +17,7 @@
 package MongoDB::_Credential;
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
@@ -163,7 +163,7 @@ sub BUILD {
     while ( my ( $key, $validator ) = each %{ $CONSTRAINTS{$mech} } ) {
         local $_ = $self->$key;
         unless ( $validator->() ) {
-            MongoDB::UsageError->throw("invalid field $key ('$_') in $mech credential");
+            MongoDB::UsageError->throw("invalid field $key in $mech credential");
         }
     }
 
