@@ -17,7 +17,7 @@
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Moo;
 use MongoDB::BSON;
@@ -37,6 +37,7 @@ use Types::Standard qw(
     InstanceOf
     Num
     Str
+    Maybe
 );
 use MongoDB::_Server;
 use Config;
@@ -150,6 +151,12 @@ has number_of_seeds => (
     isa => Num,
 );
 
+has max_election_id => (
+    is      => 'rw',
+    isa     => Maybe[ InstanceOf['MongoDB::OID'] ],
+    writer  => '_set_max_election_id',
+);
+
 # compatible wire protocol
 has is_compatible => (
     is => 'ro',
@@ -858,6 +865,21 @@ sub _update_rs_with_primary_from_primary {
         return;
     }
 
+    my $election_id = $new_server->is_master->{electionId};
+
+    if ( defined $election_id ) {
+        if ( defined $self->max_election_id
+                && $self->max_election_id->value gt $election_id->value ) {
+            # stale primary
+
+            $self->_remove_address($new_server->address);
+            $self->_add_address_as_unknown($new_server->address);
+            $self->_check_for_primary;
+            return;
+        }
+        $self->_set_max_election_id( $election_id );
+    }
+
     # possibly invalidate an old primary (even if more than one!)
     for my $old_primary ( $self->_primaries ) {
         if ( $old_primary->address ne $new_server->address ) {
