@@ -19,7 +19,7 @@ package MongoDB::_Types;
 # MongoDB type definitions
 
 use version;
-our $VERSION = 'v0.999.999.6'; # TRIAL
+our $VERSION = 'v1.1.0'; # TRIAL
 
 use Type::Library
   -base,
@@ -29,7 +29,6 @@ use Type::Library
   Booleanpm
   BSONCodec
   ConnectType
-  ConnectionStr
   CursorType
   DBRefColl
   DBRefDB
@@ -46,9 +45,11 @@ use Type::Library
   MongoDBQuery
   NonEmptyStr
   NonNegNum
+  OID
   OrderedDoc
   PairArrayRef
   ReadPrefMode
+  ReadConcern
   ReadPreference
   ServerDesc
   ServerType
@@ -73,23 +74,9 @@ use Types::Standard qw(
 );
 
 use Scalar::Util qw/reftype/;
-use boolean;
+use boolean 0.25;
 require Tie::IxHash;
 
-sub connection_uri_re {
-    return qr{
-            mongodb://
-            (?: ([^:]*) (?: : ([^@]*) )? @ )? # [username(:password)?@]
-            ([^/]*) # host1[:port1][,host2[:port2],...[,hostN[:portN]]]
-            (?:
-               / ([^?]*) # /[database]
-                (?: [?] (.*) )? # [?options]
-            )?
-    }x;
-}
-
-my $uri_re = MongoDB::_Types::connection_uri_re();
-
 #--------------------------------------------------------------------------#
 # Type declarations (without inherited coercions)
 #--------------------------------------------------------------------------#
@@ -105,10 +92,6 @@ duck_type BSONCodec, [ qw/encode_one decode_one/ ];
 
 enum ConnectType, [qw/replicaSet direct none/];
 
-declare ConnectionStr, as Str,
-  where { $_ =~ /^$uri_re$/ },
-  message { "Could not parse URI '$_'" };
-
 enum CursorType, [qw/non_tailable tailable tailable_await/];
 
 declare ErrorStr, as Str, where { $_ }; # needs a true value
@@ -142,6 +125,10 @@ declare NonNegNum, as Num,
   where { defined($_) && $_ >= 0 },
   message { "value must be a non-negative number" };
 
+declare OID, as Str, where { /\A[0-9a-f]{24}\z/ }, message {
+    "Value '$_' is not a valid OID"
+};
+
 declare PairArrayRef, as ArrayRef,
   where { @$_ % 2 == 0 };
 
@@ -150,6 +137,8 @@ enum ReadPrefMode,
 
 class_type ReadPreference, { class => 'MongoDB::ReadPreference' };
 
+class_type ReadConcern, { class => 'MongoDB::ReadConcern' };
+
 class_type ServerDesc, { class => 'MongoDB::_Server' };
 
 enum ServerType,
@@ -209,6 +198,8 @@ coerce IxHash, from ArrayRef, via { Tie::IxHash->new(@$_) };
 
 coerce IxHash, from HashLike, via { Tie::IxHash->new(%$_) };
 
+coerce OID, from Str, via { lc $_ };
+
 coerce ReadPreference, from HashRef,
   via { require MongoDB::ReadPreference; MongoDB::ReadPreference->new($_) };
 
@@ -218,6 +209,12 @@ coerce ReadPreference, from Str,
 coerce ReadPreference, from ArrayRef,
   via { require MongoDB::ReadPreference; MongoDB::ReadPreference->new( mode => $_->[0], tag_sets => $_->[1] ) };
 
+coerce ReadConcern, from Str,
+  via { require MongoDB::ReadConcern; MongoDB::ReadConcern->new( level => $_ ) };
+
+coerce ReadConcern, from HashRef,
+  via { require MongoDB::ReadConcern; MongoDB::ReadConcern->new($_) };
+
 coerce WriteConcern, from HashRef,
   via { require MongoDB::WriteConcern; MongoDB::WriteConcern->new($_) };
 
